@@ -204,38 +204,38 @@ describe('contentDisposition.parse(string)', function () {
     })
 
     it('should parse "attachment"', function () {
-      deepEqual(contentDisposition.parse('attachment'), {
+      assert.ok(deepEqual(contentDisposition.parse('attachment'), {
         type: 'attachment',
         parameters: {}
-      })
+      }))
     })
 
     it('should parse "inline"', function () {
-      deepEqual(contentDisposition.parse('inline'), {
+      assert.ok(deepEqual(contentDisposition.parse('inline'), {
         type: 'inline',
         parameters: {}
-      })
+      }))
     })
 
     it('should parse "form-data"', function () {
-      deepEqual(contentDisposition.parse('form-data'), {
+      assert.ok(deepEqual(contentDisposition.parse('form-data'), {
         type: 'form-data',
         parameters: {}
-      })
+      }))
     })
 
     it('should parse with trailing LWS', function () {
-      deepEqual(contentDisposition.parse('attachment \t '), {
+      assert.ok(deepEqual(contentDisposition.parse('attachment \t '), {
         type: 'attachment',
         parameters: {}
-      })
+      }))
     })
 
     it('should normalize to lower-case', function () {
-      deepEqual(contentDisposition.parse('ATTACHMENT'), {
+      assert.ok(deepEqual(contentDisposition.parse('ATTACHMENT'), {
         type: 'attachment',
         parameters: {}
-      })
+      }))
     })
   })
 
@@ -278,52 +278,52 @@ describe('contentDisposition.parse(string)', function () {
     })
 
     it('should lower-case parameter name', function () {
-      deepEqual(contentDisposition.parse('attachment; FILENAME="plans.pdf"'), {
+      assert.ok(deepEqual(contentDisposition.parse('attachment; FILENAME="plans.pdf"'), {
         type: 'attachment',
         parameters: { filename: 'plans.pdf' }
-      })
+      }))
     })
 
     it('should parse quoted parameter value', function () {
-      deepEqual(contentDisposition.parse('attachment; filename="plans.pdf"'), {
+      assert.ok(deepEqual(contentDisposition.parse('attachment; filename="plans.pdf"'), {
         type: 'attachment',
         parameters: { filename: 'plans.pdf' }
-      })
+      }))
     })
 
     it('should parse & unescape quoted value', function () {
-      deepEqual(contentDisposition.parse('attachment; filename="the \\"plans\\".pdf"'), {
+      assert.ok(deepEqual(contentDisposition.parse('attachment; filename="the \\"plans\\".pdf"'), {
         type: 'attachment',
         parameters: { filename: 'the "plans".pdf' }
-      })
+      }))
     })
 
     it('should include all parameters', function () {
-      deepEqual(contentDisposition.parse('attachment; filename="plans.pdf"; foo=bar'), {
+      assert.ok(deepEqual(contentDisposition.parse('attachment; filename="plans.pdf"; foo=bar'), {
         type: 'attachment',
         parameters: { filename: 'plans.pdf', foo: 'bar' }
-      })
+      }))
     })
 
     it('should parse parameters separated with any LWS', function () {
-      deepEqual(contentDisposition.parse('attachment;filename="plans.pdf" \t;    \t\t foo=bar'), {
+      assert.ok(deepEqual(contentDisposition.parse('attachment;filename="plans.pdf" \t;    \t\t foo=bar'), {
         type: 'attachment',
         parameters: { filename: 'plans.pdf', foo: 'bar' }
-      })
+      }))
     })
 
     it('should parse token filename', function () {
-      deepEqual(contentDisposition.parse('attachment; filename=plans.pdf'), {
+      assert.ok(deepEqual(contentDisposition.parse('attachment; filename=plans.pdf'), {
         type: 'attachment',
         parameters: { filename: 'plans.pdf' }
-      })
+      }))
     })
 
     it('should parse ISO-8859-1 filename', function () {
-      deepEqual(contentDisposition.parse('attachment; filename="£ rates.pdf"'), {
+      assert.ok(deepEqual(contentDisposition.parse('attachment; filename="£ rates.pdf"'), {
         type: 'attachment',
         parameters: { filename: '£ rates.pdf' }
-      })
+      }))
     })
   })
 
@@ -334,39 +334,39 @@ describe('contentDisposition.parse(string)', function () {
     })
 
     it('should parse UTF-8 extended parameter value', function () {
-      deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'%E2%82%AC%20rates.pdf'), {
+      assert.ok(deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'%E2%82%AC%20rates.pdf'), {
         type: 'attachment',
-        parameters: { 'filename': '€ rates.pdf' }
-      })
+        parameters: { filename: '€ rates.pdf' }
+      }))
     })
 
     it('should parse UTF-8 extended parameter value', function () {
-      deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'%E2%82%AC%20rates.pdf'), {
+      assert.ok(deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'%E2%82%AC%20rates.pdf'), {
         type: 'attachment',
-        parameters: { 'filename': '€ rates.pdf' }
-      })
-      deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'%E4%20rates.pdf'), {
+        parameters: { filename: '€ rates.pdf' }
+      }))
+      assert.ok(deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'%E4%20rates.pdf'), {
         type: 'attachment',
-        parameters: { 'filename': '\ufffd rates.pdf' }
-      })
+        parameters: { filename: '\ufffd rates.pdf' }
+      }))
     })
 
     it('should parse ISO-8859-1 extended parameter value', function () {
-      deepEqual(contentDisposition.parse('attachment; filename*=ISO-8859-1\'\'%A3%20rates.pdf'), {
+      assert.ok(deepEqual(contentDisposition.parse('attachment; filename*=ISO-8859-1\'\'%A3%20rates.pdf'), {
         type: 'attachment',
-        parameters: { 'filename': '£ rates.pdf' }
-      })
-      deepEqual(contentDisposition.parse('attachment; filename*=ISO-8859-1\'\'%82%20rates.pdf'), {
+        parameters: { filename: '£ rates.pdf' }
+      }))
+      assert.ok(deepEqual(contentDisposition.parse('attachment; filename*=ISO-8859-1\'\'%82%20rates.pdf'), {
         type: 'attachment',
-        parameters: { 'filename': '? rates.pdf' }
-      })
+        parameters: { filename: '? rates.pdf' }
+      }))
     })
 
     it('should not be case-sensitive for charser', function () {
-      deepEqual(contentDisposition.parse('attachment; filename*=utf-8\'\'%E2%82%AC%20rates.pdf'), {
+      assert.ok(deepEqual(contentDisposition.parse('attachment; filename*=utf-8\'\'%E2%82%AC%20rates.pdf'), {
         type: 'attachment',
-        parameters: { 'filename': '€ rates.pdf' }
-      })
+        parameters: { filename: '€ rates.pdf' }
+      }))
     })
 
     it('should reject unsupported charset', function () {
@@ -375,31 +375,31 @@ describe('contentDisposition.parse(string)', function () {
     })
 
     it('should parse with embedded language', function () {
-      deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'en\'%E2%82%AC%20rates.pdf'), {
+      assert.ok(deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'en\'%E2%82%AC%20rates.pdf'), {
         type: 'attachment',
-        parameters: { 'filename': '€ rates.pdf' }
-      })
+        parameters: { filename: '€ rates.pdf' }
+      }))
     })
 
     it('should prefer extended parameter value', function () {
-      deepEqual(contentDisposition.parse('attachment; filename="EURO rates.pdf"; filename*=UTF-8\'\'%E2%82%AC%20rates.pdf'), {
+      assert.ok(deepEqual(contentDisposition.parse('attachment; filename="EURO rates.pdf"; filename*=UTF-8\'\'%E2%82%AC%20rates.pdf'), {
         type: 'attachment',
-        parameters: { 'filename': '€ rates.pdf' }
-      })
-      deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'%E2%82%AC%20rates.pdf; filename="EURO rates.pdf"'), {
+        parameters: { filename: '€ rates.pdf' }
+      }))
+      assert.ok(deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'%E2%82%AC%20rates.pdf; filename="EURO rates.pdf"'), {
         type: 'attachment',
-        parameters: { 'filename': '€ rates.pdf' }
-      })
+        parameters: { filename: '€ rates.pdf' }
+      }))
     })
   })
 
   describe('from TC 2231', function () {
     describe('Disposition-Type Inline', function () {
       it('should parse "inline"', function () {
-        deepEqual(contentDisposition.parse('inline'), {
+        assert.ok(deepEqual(contentDisposition.parse('inline'), {
           type: 'inline',
           parameters: {}
-        })
+        }))
       })
 
       it('should reject ""inline""', function () {
@@ -408,33 +408,33 @@ describe('contentDisposition.parse(string)', function () {
       })
 
       it('should parse "inline; filename="foo.html""', function () {
-        deepEqual(contentDisposition.parse('inline; filename="foo.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('inline; filename="foo.html"'), {
           type: 'inline',
           parameters: { filename: 'foo.html' }
-        })
+        }))
       })
 
       it('should parse "inline; filename="Not an attachment!""', function () {
-        deepEqual(contentDisposition.parse('inline; filename="Not an attachment!"'), {
+        assert.ok(deepEqual(contentDisposition.parse('inline; filename="Not an attachment!"'), {
           type: 'inline',
           parameters: { filename: 'Not an attachment!' }
-        })
+        }))
       })
 
       it('should parse "inline; filename="foo.pdf""', function () {
-        deepEqual(contentDisposition.parse('inline; filename="foo.pdf"'), {
+        assert.ok(deepEqual(contentDisposition.parse('inline; filename="foo.pdf"'), {
           type: 'inline',
           parameters: { filename: 'foo.pdf' }
-        })
+        }))
       })
     })
 
     describe('Disposition-Type Attachment', function () {
       it('should parse "attachment"', function () {
-        deepEqual(contentDisposition.parse('attachment'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment'), {
           type: 'attachment',
           parameters: {}
-        })
+        }))
       })
 
       it('should reject ""attachment""', function () {
@@ -443,80 +443,80 @@ describe('contentDisposition.parse(string)', function () {
       })
 
       it('should parse "ATTACHMENT"', function () {
-        deepEqual(contentDisposition.parse('ATTACHMENT'), {
+        assert.ok(deepEqual(contentDisposition.parse('ATTACHMENT'), {
           type: 'attachment',
           parameters: {}
-        })
+        }))
       })
 
       it('should parse "attachment; filename="foo.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="foo.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="foo.html"'), {
           type: 'attachment',
           parameters: { filename: 'foo.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename="0000000000111111111122222""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="0000000000111111111122222"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="0000000000111111111122222"'), {
           type: 'attachment',
           parameters: { filename: '0000000000111111111122222' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename="00000000001111111111222222222233333""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="00000000001111111111222222222233333"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="00000000001111111111222222222233333"'), {
           type: 'attachment',
           parameters: { filename: '00000000001111111111222222222233333' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename="f\\oo.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="f\\oo.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="f\\oo.html"'), {
           type: 'attachment',
           parameters: { filename: 'foo.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename="\\"quoting\\" tested.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="\\"quoting\\" tested.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="\\"quoting\\" tested.html"'), {
           type: 'attachment',
           parameters: { filename: '"quoting" tested.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename="Here\'s a semicolon;.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="Here\'s a semicolon;.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="Here\'s a semicolon;.html"'), {
           type: 'attachment',
           parameters: { filename: 'Here\'s a semicolon;.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; foo="bar"; filename="foo.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; foo="bar"; filename="foo.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; foo="bar"; filename="foo.html"'), {
           type: 'attachment',
           parameters: { filename: 'foo.html', foo: 'bar' }
-        })
+        }))
       })
 
       it('should parse "attachment; foo="\\"\\\\";filename="foo.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; foo="\\"\\\\";filename="foo.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; foo="\\"\\\\";filename="foo.html"'), {
           type: 'attachment',
           parameters: { filename: 'foo.html', foo: '"\\' }
-        })
+        }))
       })
 
       it('should parse "attachment; FILENAME="foo.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; FILENAME="foo.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; FILENAME="foo.html"'), {
           type: 'attachment',
           parameters: { filename: 'foo.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename=foo.html"', function () {
-        deepEqual(contentDisposition.parse('attachment; filename=foo.html'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename=foo.html'), {
           type: 'attachment',
           parameters: { filename: 'foo.html' }
-        })
+        }))
       })
 
       it('should reject "attachment; filename=foo,bar.html"', function () {
@@ -540,73 +540,73 @@ describe('contentDisposition.parse(string)', function () {
       })
 
       it('should parse "attachment; filename=\'foo.bar\'', function () {
-        deepEqual(contentDisposition.parse('attachment; filename=\'foo.bar\''), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename=\'foo.bar\''), {
           type: 'attachment',
           parameters: { filename: '\'foo.bar\'' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename="foo-ä.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="foo-ä.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="foo-ä.html"'), {
           type: 'attachment',
           parameters: { filename: 'foo-ä.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename="foo-Ã¤.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="foo-Ã¤.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="foo-Ã¤.html"'), {
           type: 'attachment',
           parameters: { filename: 'foo-Ã¤.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename="foo-%41.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="foo-%41.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="foo-%41.html"'), {
           type: 'attachment',
           parameters: { filename: 'foo-%41.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename="50%.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="50%.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="50%.html"'), {
           type: 'attachment',
           parameters: { filename: '50%.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename="foo-%\\41.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="foo-%\\41.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="foo-%\\41.html"'), {
           type: 'attachment',
           parameters: { filename: 'foo-%41.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; name="foo-%41.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; name="foo-%41.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; name="foo-%41.html"'), {
           type: 'attachment',
           parameters: { name: 'foo-%41.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename="ä-%41.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="ä-%41.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="ä-%41.html"'), {
           type: 'attachment',
           parameters: { filename: 'ä-%41.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename="foo-%c3%a4-%e2%82%ac.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="foo-%c3%a4-%e2%82%ac.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="foo-%c3%a4-%e2%82%ac.html"'), {
           type: 'attachment',
           parameters: { filename: 'foo-%c3%a4-%e2%82%ac.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename ="foo.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename ="foo.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename ="foo.html"'), {
           type: 'attachment',
           parameters: { filename: 'foo.html' }
-        })
+        }))
       })
 
       it('should reject "attachment; filename="foo.html"; filename="bar.html"', function () {
@@ -710,72 +710,72 @@ describe('contentDisposition.parse(string)', function () {
       })
 
       it('should parse "attachment; xfilename=foo.html"', function () {
-        deepEqual(contentDisposition.parse('attachment; xfilename=foo.html'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; xfilename=foo.html'), {
           type: 'attachment',
           parameters: { xfilename: 'foo.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename="/foo.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="/foo.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="/foo.html"'), {
           type: 'attachment',
           parameters: { filename: '/foo.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename="\\\\foo.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="\\\\foo.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="\\\\foo.html"'), {
           type: 'attachment',
           parameters: { filename: '\\foo.html' }
-        })
+        }))
       })
     })
 
     describe('Additional Parameters', function () {
       it('should parse "attachment; creation-date="Wed, 12 Feb 1997 16:29:51 -0500""', function () {
-        deepEqual(contentDisposition.parse('attachment; creation-date="Wed, 12 Feb 1997 16:29:51 -0500"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; creation-date="Wed, 12 Feb 1997 16:29:51 -0500"'), {
           type: 'attachment',
           parameters: { 'creation-date': 'Wed, 12 Feb 1997 16:29:51 -0500' }
-        })
+        }))
       })
 
       it('should parse "attachment; modification-date="Wed, 12 Feb 1997 16:29:51 -0500""', function () {
-        deepEqual(contentDisposition.parse('attachment; modification-date="Wed, 12 Feb 1997 16:29:51 -0500"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; modification-date="Wed, 12 Feb 1997 16:29:51 -0500"'), {
           type: 'attachment',
           parameters: { 'modification-date': 'Wed, 12 Feb 1997 16:29:51 -0500' }
-        })
+        }))
       })
     })
 
     describe('Disposition-Type Extension', function () {
       it('should parse "foobar"', function () {
-        deepEqual(contentDisposition.parse('foobar'), {
+        assert.ok(deepEqual(contentDisposition.parse('foobar'), {
           type: 'foobar',
           parameters: {}
-        })
+        }))
       })
 
       it('should parse "attachment; example="filename=example.txt""', function () {
-        deepEqual(contentDisposition.parse('attachment; example="filename=example.txt"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; example="filename=example.txt"'), {
           type: 'attachment',
           parameters: { example: 'filename=example.txt' }
-        })
+        }))
       })
     })
 
     describe('RFC 2231/5987 Encoding: Character Sets', function () {
       it('should parse "attachment; filename*=iso-8859-1\'\'foo-%E4.html"', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*=iso-8859-1\'\'foo-%E4.html'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*=iso-8859-1\'\'foo-%E4.html'), {
           type: 'attachment',
           parameters: { filename: 'foo-ä.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename*=UTF-8\'\'foo-%c3%a4-%e2%82%ac.html"', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'foo-%c3%a4-%e2%82%ac.html'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'foo-%c3%a4-%e2%82%ac.html'), {
           type: 'attachment',
           parameters: { filename: 'foo-ä-€.html' }
-        })
+        }))
       })
 
       it('should reject "attachment; filename*=\'\'foo-%c3%a4-%e2%82%ac.html"', function () {
@@ -784,24 +784,24 @@ describe('contentDisposition.parse(string)', function () {
       })
 
       it('should parse "attachment; filename*=UTF-8\'\'foo-a%cc%88.html"', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'foo-a%cc%88.html'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'foo-a%cc%88.html'), {
           type: 'attachment',
           parameters: { filename: 'foo-ä.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename*=iso-8859-1\'\'foo-%c3%a4-%e2%82%ac.html"', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*=iso-8859-1\'\'foo-%c3%a4-%e2%82%ac.html'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*=iso-8859-1\'\'foo-%c3%a4-%e2%82%ac.html'), {
           type: 'attachment',
           parameters: { filename: 'foo-Ã¤-â?¬.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename*=utf-8\'\'foo-%E4.html"', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*=utf-8\'\'foo-%E4.html'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*=utf-8\'\'foo-%E4.html'), {
           type: 'attachment',
           parameters: { filename: 'foo-\ufffd.html' }
-        })
+        }))
       })
 
       it('should reject "attachment; filename *=UTF-8\'\'foo-%c3%a4.html"', function () {
@@ -810,17 +810,17 @@ describe('contentDisposition.parse(string)', function () {
       })
 
       it('should parse "attachment; filename*= UTF-8\'\'foo-%c3%a4.html"', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*= UTF-8\'\'foo-%c3%a4.html'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*= UTF-8\'\'foo-%c3%a4.html'), {
           type: 'attachment',
           parameters: { filename: 'foo-ä.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename* =UTF-8\'\'foo-%c3%a4.html"', function () {
-        deepEqual(contentDisposition.parse('attachment; filename* =UTF-8\'\'foo-%c3%a4.html'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename* =UTF-8\'\'foo-%c3%a4.html'), {
           type: 'attachment',
           parameters: { filename: 'foo-ä.html' }
-        })
+        }))
       })
 
       it('should reject "attachment; filename*="UTF-8\'\'foo-%c3%a4.html""', function () {
@@ -849,98 +849,98 @@ describe('contentDisposition.parse(string)', function () {
       })
 
       it('should parse "attachment; filename*=UTF-8\'\'A-%2541.html"', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'A-%2541.html'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'A-%2541.html'), {
           type: 'attachment',
           parameters: { filename: 'A-%41.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename*=UTF-8\'\'%5cfoo.html"', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'%5cfoo.html'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'%5cfoo.html'), {
           type: 'attachment',
           parameters: { filename: '\\foo.html' }
-        })
+        }))
       })
     })
 
     describe('RFC2231 Encoding: Continuations', function () {
       it('should parse "attachment; filename*0="foo."; filename*1="html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*0="foo."; filename*1="html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*0="foo."; filename*1="html"'), {
           type: 'attachment',
           parameters: { 'filename*0': 'foo.', 'filename*1': 'html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename*0="foo"; filename*1="\\b\\a\\r.html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*0="foo"; filename*1="\\b\\a\\r.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*0="foo"; filename*1="\\b\\a\\r.html"'), {
           type: 'attachment',
           parameters: { 'filename*0': 'foo', 'filename*1': 'bar.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename*0*=UTF-8\'\'foo-%c3%a4; filename*1=".html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*0*=UTF-8\'\'foo-%c3%a4; filename*1=".html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*0*=UTF-8\'\'foo-%c3%a4; filename*1=".html"'), {
           type: 'attachment',
           parameters: { 'filename*0*': 'UTF-8\'\'foo-%c3%a4', 'filename*1': '.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename*0="foo"; filename*01="bar""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*0="foo"; filename*01="bar"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*0="foo"; filename*01="bar"'), {
           type: 'attachment',
           parameters: { 'filename*0': 'foo', 'filename*01': 'bar' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename*0="foo"; filename*2="bar""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*0="foo"; filename*2="bar"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*0="foo"; filename*2="bar"'), {
           type: 'attachment',
           parameters: { 'filename*0': 'foo', 'filename*2': 'bar' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename*1="foo."; filename*2="html""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*1="foo."; filename*2="html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*1="foo."; filename*2="html"'), {
           type: 'attachment',
           parameters: { 'filename*1': 'foo.', 'filename*2': 'html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename*1="bar"; filename*0="foo""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*1="bar"; filename*0="foo"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*1="bar"; filename*0="foo"'), {
           type: 'attachment',
           parameters: { 'filename*1': 'bar', 'filename*0': 'foo' }
-        })
+        }))
       })
     })
 
     describe('RFC2231 Encoding: Fallback Behaviour', function () {
       it('should parse "attachment; filename="foo-ae.html"; filename*=UTF-8\'\'foo-%c3%a4.html"', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="foo-ae.html"; filename*=UTF-8\'\'foo-%c3%a4.html'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="foo-ae.html"; filename*=UTF-8\'\'foo-%c3%a4.html'), {
           type: 'attachment',
           parameters: { filename: 'foo-ä.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename*=UTF-8\'\'foo-%c3%a4.html; filename="foo-ae.html"', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'foo-%c3%a4.html; filename="foo-ae.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*=UTF-8\'\'foo-%c3%a4.html; filename="foo-ae.html"'), {
           type: 'attachment',
           parameters: { filename: 'foo-ä.html' }
-        })
+        }))
       })
 
       it('should parse "attachment; filename*0*=ISO-8859-15\'\'euro-sign%3d%a4; filename*=ISO-8859-1\'\'currency-sign%3d%a4', function () {
-        deepEqual(contentDisposition.parse('attachment; filename*0*=ISO-8859-15\'\'euro-sign%3d%a4; filename*=ISO-8859-1\'\'currency-sign%3d%a4'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename*0*=ISO-8859-15\'\'euro-sign%3d%a4; filename*=ISO-8859-1\'\'currency-sign%3d%a4'), {
           type: 'attachment',
           parameters: { filename: 'currency-sign=¤', 'filename*0*': 'ISO-8859-15\'\'euro-sign%3d%a4' }
-        })
+        }))
       })
 
       it('should parse "attachment; foobar=x; filename="foo.html"', function () {
-        deepEqual(contentDisposition.parse('attachment; foobar=x; filename="foo.html"'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; foobar=x; filename="foo.html"'), {
           type: 'attachment',
           parameters: { filename: 'foo.html', foobar: 'x' }
-        })
+        }))
       })
     })
 
@@ -951,10 +951,10 @@ describe('contentDisposition.parse(string)', function () {
       })
 
       it('should parse "attachment; filename="=?ISO-8859-1?Q?foo-=E4.html?=""', function () {
-        deepEqual(contentDisposition.parse('attachment; filename="=?ISO-8859-1?Q?foo-=E4.html?="'), {
+        assert.ok(deepEqual(contentDisposition.parse('attachment; filename="=?ISO-8859-1?Q?foo-=E4.html?="'), {
           type: 'attachment',
           parameters: { filename: '=?ISO-8859-1?Q?foo-=E4.html?=' }
-        })
+        }))
       })
     })
   })
